@@ -34,16 +34,13 @@ sample = '''
     '''
 
 # syntax we don't want to see in the final parse tree
-_lcurl = Suppress('{')
-_rcurl = Suppress('}')
-_equal = Suppress('=')
-_comma = Suppress(',')
+LBRACE,RBRACE,EQ,COMMA = map(Suppress,"{}=,")
 _enum = Suppress('enum')
 identifier = Word(alphas,alphanums+'_')
 integer = Word(nums)
-enumValue = Group(identifier('name') + Optional(_equal + integer('value')))
-enumList = Group(enumValue + ZeroOrMore(_comma + enumValue))
-enum = _enum + identifier('enum') + _lcurl + enumList('list') + _rcurl
+enumValue = Group(identifier('name') + Optional(EQ + integer('value')))
+enumList = Group(enumValue + ZeroOrMore(COMMA + enumValue))
+enum = _enum + identifier('enum') + LBRACE + enumList('list') + RBRACE
 
 # find instances of enums ignoring other syntax
 for item,start,stop in enum.scanString(sample):
